@@ -1,28 +1,46 @@
 import graphene
 from dagster import check
-from dagster.core.host_representation import ExternalSensor, SensorSelector
+from dagster.core.host_representation import ExternalSensor, ExternalTargetData, SensorSelector
 from dagster.core.scheduler.job import JobState
-from dagster_graphql.implementation.utils import capture_error, check_read_only
+from dagster.core.workspace.permissions import Permissions
+from dagster_graphql.implementation.utils import capture_error, check_permission
 
 from ..implementation.fetch_sensors import get_sensor_next_tick, start_sensor, stop_sensor
 from .errors import (
     GraphenePythonError,
-    GrapheneReadOnlyError,
     GrapheneRepositoryNotFoundError,
     GrapheneSensorNotFoundError,
+    GrapheneUnauthorizedError,
 )
 from .inputs import GrapheneSensorSelector
 from .instigation import GrapheneFutureInstigationTick, GrapheneInstigationState
 from .util import non_null_list
 
 
+class GrapheneTarget(graphene.ObjectType):
+    pipelineName = graphene.NonNull(graphene.String)
+    mode = graphene.NonNull(graphene.String)
+    solidSelection = graphene.List(graphene.NonNull(graphene.String))
+
+    class Meta:
+        name = "Target"
+
+    def __init__(self, external_target):
+        self._external_target = check.inst_param(
+            external_target, "external_target", ExternalTargetData
+        )
+        super().__init__(
+            pipelineName=external_target.pipeline_name,
+            mode=external_target.mode,
+            solidSelection=external_target.solid_selection,
+        )
+
+
 class GrapheneSensor(graphene.ObjectType):
     id = graphene.NonNull(graphene.ID)
     jobOriginId = graphene.NonNull(graphene.String)
     name = graphene.NonNull(graphene.String)
-    pipelineName = graphene.String()
-    solidSelection = graphene.List(graphene.String)
-    mode = graphene.String()
+    targets = graphene.List(graphene.NonNull(GrapheneTarget))
     sensorState = graphene.NonNull(GrapheneInstigationState)
     minIntervalSeconds = graphene.NonNull(graphene.Int)
     description = graphene.String()
@@ -47,11 +65,9 @@ class GrapheneSensor(graphene.ObjectType):
         super().__init__(
             name=external_sensor.name,
             jobOriginId=external_sensor.get_external_origin_id(),
-            pipelineName=external_sensor.pipeline_name,
-            solidSelection=external_sensor.solid_selection,
-            mode=external_sensor.mode,
             minIntervalSeconds=external_sensor.min_interval_seconds,
             description=external_sensor.description,
+            targets=[GrapheneTarget(target) for target in external_sensor.get_external_targets()],
         )
 
     def resolve_id(self, _):
@@ -69,7 +85,7 @@ class GrapheneSensorOrError(graphene.Union):
         types = (
             GrapheneSensor,
             GrapheneSensorNotFoundError,
-            GrapheneReadOnlyError,
+            GrapheneUnauthorizedError,
             GraphenePythonError,
         )
         name = "SensorOrError"
@@ -98,7 +114,7 @@ class GrapheneStartSensorMutation(graphene.Mutation):
         name = "StartSensorMutation"
 
     @capture_error
-    @check_read_only
+    @check_permission(Permissions.START_SENSOR)
     def mutate(self, graphene_info, sensor_selector):
         return start_sensor(graphene_info, SensorSelector.from_graphql_input(sensor_selector))
 
@@ -122,7 +138,7 @@ class GrapheneStopSensorMutationResult(graphene.ObjectType):
 
 class GrapheneStopSensorMutationResultOrError(graphene.Union):
     class Meta:
-        types = (GrapheneStopSensorMutationResult, GrapheneReadOnlyError, GraphenePythonError)
+        types = (GrapheneStopSensorMutationResult, GrapheneUnauthorizedError, GraphenePythonError)
         name = "StopSensorMutationResultOrError"
 
 
@@ -136,7 +152,7 @@ class GrapheneStopSensorMutation(graphene.Mutation):
         name = "StopSensorMutation"
 
     @capture_error
-    @check_read_only
+    @check_permission(Permissions.STOP_SENSOR)
     def mutate(self, graphene_info, job_origin_id):
         return stop_sensor(graphene_info, job_origin_id)
 
