@@ -13,6 +13,5 @@ def test_dagster_out_of_process_location():
             python_file=file_relative_path(__file__, "setup.py"),
             attribute="test_repo",
         ),
-    ).create_handle() as handle:
-        env = handle.create_location()
+    ).create_test_location() as env:
         assert env.get_repository("test_repo")
